@@ -36,9 +36,15 @@ OC.L10N.register(
     "Message sent!" : "تم الإرسال الرسالة!",
     "Send" : "أرسل",
     "Choose a file to add as attachment" : "اختر ملف لإضافته كمرفق",
+    "Choose a file to share as a link" : "اختر ملفا لمشاركته كرابط",
     "Draft: " : "المسودة:",
     "Favorite" : "المفضلة",
+    "Unselect" : "إلغاء التحديد",
+    "Select" : "تحديد",
     "Delete" : "حذف",
+    "Important" : "مهم",
+    "Favorites" : "المفضلات",
+    "Other" : "آخر",
     "Not found" : "غير موجود",
     "to" : "إلى",
     "cc" : "نسخة كربونية",
@@ -51,13 +57,17 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "اختر مجلد لتخزين المرفقات ",
     "Save all to Files" : "حفظ الجميع لـ الملفات",
     "The images have been blocked to protect your privacy." : "تم حجب هذه الصورة لحماية خصوصيتك",
+    "Show images from this sender" : "أظهر الصور من هذا المُرسل",
     "New message" : "رسالة جديدة",
     "Settings" : "الإعدادات",
+    "Quota" : "الحصة",
     "Add folder" : "إضافة مجلد",
-    "Delete account" : "حذف الحساب",
+    "Remove account" : "حذف حساب",
+    "Cancel" : "إلغاء",
     "Show all folders" : "أظهر جميع المجلدات",
     "Collapse folders" : "طي المجلدات",
     "Mark all as read" : "تحديد الكل كمقروء",
+    "Clear cache" : "مسح ذاكرة التخزين المؤقتة",
     "Signature" : "التوقيع",
     "General" : "العامة",
     "Email address" : "عنوان البريد الإلكتروني",
@@ -77,7 +87,6 @@ OC.L10N.register(
     "All" : "الكل",
     "Archive" : "الأرشيف",
     "Drafts" : "المسودات",
-    "Favorites" : "المفضلات",
     "All inboxes" : "جميع الوارد",
     "Inbox" : "صندوق الوارد",
     "Junk" : "عشوائي",
