@@ -22,17 +22,24 @@ OC.L10N.register(
     "Message sent!" : "Mesaj trimis!",
     "Send" : "Trimite",
     "Favorite" : "Favorite",
+    "Select" : "Select",
     "Delete" : "Șterge",
+    "Important" : "Important",
+    "Favorites" : "Favorite",
+    "Other" : "Altele",
     "to" : "către",
     "Reply" : "Răspunde",
     "Unnamed" : "Fără nume",
     "Choose a folder to store the attachment in" : "Alege un dosar în care să stochez atașamentul",
     "Settings" : "Setări",
+    "Quota" : "Procent",
     "Add folder" : "Add folder",
-    "Delete account" : "Delete account",
+    "Remove account" : "Sterge contul",
+    "Loading …" : "Se încarcă…",
+    "Cancel" : "Anulează",
     "Show all folders" : "Arată toate directoarele",
     "Mark all as read" : "Marcaţi tot ca fiind citit",
-    "Loading …" : "Se încarcă…",
+    "Clear cache" : "Șterge cache",
     "Signature" : "Semnătură",
     "General" : "General",
     "User" : "Utilizator",
@@ -43,7 +50,6 @@ OC.L10N.register(
     "All" : "Toate ",
     "Archive" : "Arhivă",
     "Drafts" : "Schițe",
-    "Favorites" : "Favorite",
     "Sent" : "Trimis",
     "Trash" : "Gunoi",
     "{from}\n{subject}" : "{from}\n{subject}",
