@@ -13,13 +13,20 @@ OC.L10N.register(
     "Go back" : "Quay lại",
     "Send" : "Gởi",
     "Favorite" : "Ưa thích",
+    "Select" : "Select",
     "Delete" : "Xóa",
+    "Important" : "Quan trọng",
+    "Favorites" : "Ưa thích",
+    "Other" : "Khác",
     "to" : "đến",
     "Reply" : "Trả l",
     "Settings" : "Thiết lập",
+    "Quota" : "Hạn ngạch",
     "Add folder" : "Add folder",
-    "Delete account" : "Delete account",
+    "Remove account" : "Xóa tài khoản",
+    "Cancel" : "Hủy bỏ",
     "Mark all as read" : "Đánh dấu tất cả như đã ",
+    "Clear cache" : "Xóa bộ nhớ ",
     "Signature" : "Chữ ký",
     "General" : "Tổng hợp",
     "User" : "Người dùng",
@@ -29,7 +36,6 @@ OC.L10N.register(
     "Refresh" : "Làm mới",
     "All" : "Tất cả",
     "Archive" : "Lưu trữ",
-    "Favorites" : "Ưa thích",
     "Sent" : "Đã gửi",
     "Trash" : "Thùng rác"
 },
