@@ -23,7 +23,6 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Model;
 
-use Horde_Mail_Rfc822_List;
 use OCA\Mail\AddressList;
 use OCA\Mail\Db\LocalAttachment;
 use OCP\Files\File;
@@ -56,7 +55,7 @@ interface IMessage {
 	public function getFrom(): AddressList;
 
 	/**
-	 * @param string $from
+	 * @param AddressList $from
 	 */
 	public function setFrom(AddressList $from);
 
